# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Test-EOL
Version:	2.02
Release:	8.%{__distinit}%{__distvers}
Summary:	Check the correct line endings in your project
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Test-EOL
Source0:	https://cpan.metacpan.org/modules/by-module/Test/Test-EOL-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(Cwd)
BuildRequires:	perl(File::Find)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(strict)
BuildRequires:	perl(Test::Builder)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(Config)
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(Test::More) >= 0.88
# Optional Tests
BuildRequires:	perl(CPAN::Meta) >= 2.120900
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

%description
This module scans your project/distribution for any perl files (scripts,
modules, etc.) with Windows line endings. It can also check for trailing
whitespace.

%prep
%setup -q -n Test-EOL-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%license LICENCE
%doc Changes CONTRIBUTING README
%{perl_vendorlib}/Test/
%{_mandir}/man3/Test::EOL.3*

%changelog
* Wed May 24 2023 aul Howarth <paul@city-fan.org> - 2.02-8
- Use SPDX-format license tag
- Use %%license unconditionally

* Mon Dec  7 2020 Paul Howarth <paul@city-fan.org> - 2.02-1
- Update to 2.02
  - Better matching on files, directories to be ignored, e.g. no longer
    confuses directory "vincent" for "inc" (CPAN RT#133862, GH#1)
  - Handle long @INC lines by passing through $PERL5LIB (CPAN RT#123448)

* Tue Jun  4 2019 Paul Howarth <paul@city-fan.org> - 2.00-8
- Perl 5.30 rebuild

* Tue Apr 10 2018 Paul Howarth <paul@city-fan.org> - 2.00-4
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl

* Thu May  4 2017 Paul Howarth <paul@city-fan.org> - 2.00-1
- Update to 2.00
  - Update documentation for starting point change in version 1.5
  - Check *.pod files as well as *.pm, *.pl and *.t (CPAN RT#82032)
  - Repository has moved to GitHub
- This release by ETHER → update source URL
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop workaround for building with Test::More < 0.88

* Fri Sep 30 2016 Paul Howarth <paul@city-fan.org> - 1.6-3
- BR: perl-generators where available
- Simplify find command using -delete

* Fri Jul 31 2015 Paul Howarth <paul@city-fan.org> - 1.6-1
- Update to 1.6
  - Add 'no_test' import option to allow more composability
- This release by FREW → update source URL
- Add patch to support building with Test::More < 0.88

* Thu Sep 11 2014 Paul Howarth <paul@city-fan.org> - 1.5-6
- Drop support for building with ExtUtils::MakeMaker < 6.30
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible
- Classify buildreqs by usage

* Sun Sep  9 2012 Paul Howarth <paul@city-fan.org> - 1.5-1
- Update to 1.5
  - Properly fix Win32 (CPAN RT#76037)
  - Change default to searching for trailing whitespace from the current
    directory downwards (as tests are run from the top of a dist normally),
    rather than one directory above the test file, as then we don't work as
    expected if tests are in t/author or similar (CPAN RT#66177)
- BR: perl(File::Temp), needed by test suite

* Sun Jul  8 2012 Paul Howarth <paul@city-fan.org> - 1.3-2
- Perl 5.16 rebuild

* Sun Jun 17 2012 Paul Howarth <paul@city-fan.org> - 1.3-1
- Update to 1.3
  - Fix to ignore inc/ directory used by Module::Install

* Fri Jun 15 2012 Paul Howarth <paul@city-fan.org> - 1.2-1
- Update to 1.2
  - Fix bad regex matching directories containing 'svn', not just '.svn'
    directories (CPAN RT#75968)
- BR: perl(Cwd)
- Drop non-dual-lived buildreqs perl(File::Find) and perl(FindBin)
- This release by BOBTFISH -> update source URL
- Remove tabs from bundled Module::Install that break release tests
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Mon Jan 16 2012 Paul Howarth <paul@city-fan.org> - 1.1-1
- Update to 1.1
  - Fix test fails on < 5.8 perls
  - Fix t/13-latin1.t failures on Win32 and under TB1.5
- Add buildreqs for required core modules, which might be dual-lived

* Thu Jan  5 2012 Paul Howarth <paul@city-fan.org> - 1.0-1
- Update to 1.0
  - Fix misleading test failure diagnostics when only issue is trailing
    whitespace
  - No longer blindly assume utf8 on input files (CPAN RT#59877)
  - Properly document testing options
- This release by RIBASUSHI -> update source URL
- Drop upstreamed patch for CPAN RT#59877
- Update patch for building with old ExtUtils::MakeMaker versions

* Sat Jul  2 2011 Paul Howarth <paul@city-fan.org> - 0.9-4
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Mon Oct 18 2010 Paul Howarth <paul@city-fan.org> - 0.9-3
- Don't assume tested files are UTF-8 encoded (CPAN RT#59877)

* Thu Jun 24 2010 Paul Howarth <paul@city-fan.org> - 0.9-2
- Rebuild for perl 5.12.1 in Rawhide

* Wed Jun 16 2010 Paul Howarth <paul@city-fan.org> - 0.9-1
- Update to 0.9 (fix warnings on very old perls - CPAN RT#58442)
- Patch for CPAN RT#58442 upstreamed

* Wed Jun 16 2010 Paul Howarth <paul@city-fan.org> - 0.8-1
- Initial RPM version
